Python demos - DPRS
Author: Colin P. Stark
Description: Directed percolation and related models implemented in Rust and wrapped in Python.

Skip to content

# Python demos

Simplified DP-class Domany-Kinzel model simulations are demonstrated in the Python scripts below.

Figure 1: 2d DP \(t\)-decay of mean order parameter \(\overline\rho(t)\), for \(p_c \approx p=0.163145\), \(n_x=30000\), \(n_y=30000\), \(t=50000\)

Quick tests to check all is working:

- dp_test_1d.py

- dp_test_2d.py

- dp_test_3d.py

More substantial simulations:

- dp_fullcheck_1d.py

- dp_fullcheck_2d.py

- dp_fullcheck_3d.py